==> jonas-JONAS_5_0_5.tar: jonas-JONAS_5_0_5/modules/ee-components/jonas-admin/src/main/java/org/ow2/jonas/webapp/jonasadmin/clusterd/ClusterDaemonItem.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2003-2005 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.webapp.jonasadmin.clusterd;

import javax.management.ObjectName;

import org.ow2.jonas.webapp.jonasadmin.common.ObjectNameItem;


public class ClusterDaemonItem extends ObjectNameItem {
    /**
     *
     */
    private static final long serialVersionUID = 0L;
    /**
     * server state
     */
    private String state = null;
    /**
     * url used to connect on JMX remote server
     */
    private String url = null;
    /**
     * the cd name
     */
    private String name = null;


    public ClusterDaemonItem(ObjectName pObjectName, String pState) {
        super(pObjectName);
        this.state = pState;
    }

    /**
     * @return Returns the url.
     */
    public String getUrl() {
        return url;
    }

    /**
     * @param url The url to set.
     */
    public void setUrl(String url) {
        this.url = url;
    }

    /**
     * @return Returns the state.
     */
    public String getState() {
        return state;
    }

    /**
     * @param state The state to set.
     */
    public void setState(String state) {
        this.state = state;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

}

==> jonas-JONAS_5_1_1.tar: jonas-JONAS_5_1_1/modules/ee-components/jonas-admin/src/main/java/org/ow2/jonas/webapp/jonasadmin/clusterd/ClusterDaemonItem.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2003-2005 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.webapp.jonasadmin.clusterd;

import javax.management.ObjectName;

import org.ow2.jonas.lib.management.extensions.base.mbean.ObjectNameItem;


public class ClusterDaemonItem extends ObjectNameItem {
    /**
     *
     */
    private static final long serialVersionUID = 0L;
    /**
     * server state
     */
    private String state = null;
    /**
     * url used to connect on JMX remote server
     */
    private String url = null;
    /**
     * the cd name
     */
    private String name = null;


    public ClusterDaemonItem(ObjectName pObjectName, String pState) {
        super(pObjectName);
        this.state = pState;
    }

    /**
     * @return Returns the url.
     */
    public String getUrl() {
        return url;
    }

    /**
     * @param url The url to set.
     */
    public void setUrl(String url) {
        this.url = url;
    }

    /**
     * @return Returns the state.
     */
    public String getState() {
        return state;
    }

    /**
     * @param state The state to set.
     */
    public void setState(String state) {
        this.state = state;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

}
